@@ -1,6 +1,6 @@
 var group__pw__keys =
 [
-    [ "src/pipewire/keys.h", "src_2pipewire_2keys_8h.html", null ],
+    [ "keys.h", "src_2pipewire_2keys_8h.html", null ],
     [ "PW_KEY_PROTOCOL", "group__pw__keys.html#ga75a6c78ce2de6d3dc5ed23abecdbc3bd", null ],
     [ "PW_KEY_ACCESS", "group__pw__keys.html#gad1bfca30c613b28723527132429bb342", null ],
     [ "PW_KEY_CLIENT_ACCESS", "group__pw__keys.html#ga550a0954601e7bf139955115f4b1c030", null ],
@@ -8,6 +8,7 @@ var group__pw__keys =
     [ "PW_KEY_SEC_UID", "group__pw__keys.html#gad6000734888b498669ad7aebcee155eb", null ],
     [ "PW_KEY_SEC_GID", "group__pw__keys.html#ga6abeb07b483a60e05f60224f7a5aae34", null ],
     [ "PW_KEY_SEC_LABEL", "group__pw__keys.html#ga9cde0fd069af370dd80ad3deac5ee053", null ],
+    [ "PW_KEY_SEC_SOCKET", "group__pw__keys.html#ga87eb3682a9910c4ff020e7be33296ad1", null ],
     [ "PW_KEY_LIBRARY_NAME_SYSTEM", "group__pw__keys.html#gada76163a82aae28e7563c6c28eddc5ea", null ],
     [ "PW_KEY_LIBRARY_NAME_LOOP", "group__pw__keys.html#ga62381a633016e0f980878eaa018ef429", null ],
     [ "PW_KEY_LIBRARY_NAME_DBUS", "group__pw__keys.html#ga32748e803174c4983e3f5378fcbe0e87", null ],
@@ -16,6 +17,7 @@ var group__pw__keys =
     [ "PW_KEY_OBJECT_SERIAL", "group__pw__keys.html#gaeacddc61cce1b3b44562edc0d11bcc85", null ],
     [ "PW_KEY_OBJECT_LINGER", "group__pw__keys.html#ga3d5bd6f00b3c9a8d89e42aa6c3f8cb58", null ],
     [ "PW_KEY_OBJECT_REGISTER", "group__pw__keys.html#ga615dfda75e0fc56ae2f2f18a6acdae9c", null ],
+    [ "PW_KEY_OBJECT_EXPORT", "group__pw__keys.html#ga754b9d36815e18e374025a001b829457", null ],
     [ "PW_KEY_CONFIG_PREFIX", "group__pw__keys.html#ga547e340cc89d32b3c2378ec365c23c6c", null ],
     [ "PW_KEY_CONFIG_NAME", "group__pw__keys.html#gaa2b0c7062965986d9d8dbadf553eb6ba", null ],
     [ "PW_KEY_CONFIG_OVERRIDE_PREFIX", "group__pw__keys.html#gaa712c1b4d85db29266abc6f89994e375", null ],
